#!/usr/bin/env python
"""

    Module containing Python port of setlodkeywd.cl script for CDBS file
    delivery support.

    :Author: Christopher Hanley

"""

from __future__ import division
import os,sys
import pyfits

import helper

def setlodkeywd(fitsfile, lodfile, comments=True, change_level="MODERATE",
                opus_flag='Y', pedigree="INFLIGHT"):
    """

    Purpose
    =======
    setlodkeywd: Function used to populate "lod" files with meta-data not
    contained in the source FITS files.

    """
    # Extract COMMENT, DESCRIP, and HISTORY from the primary header of the
    # fits file and store it in a list object
    hdulist = pyfits.open(fitsfile)
    fitslist = hdulist[0].header.ascardlist()
    fitshist = []
    for key in ['COMMENT', 'DESCRIP', 'HISTORY']:
        for line in fitslist:
            if line.key == key:
                fitshist.append(str(line.value)+'\n')


    # Open the current LODFILE for reading
    filehandle = open(lodfile,'r')

    # Read all the lines of the LODFILE into a list.
    filelist = filehandle.readlines()

    # Initalize COMMENT line list
    commentLineList = []
    lineNumber = 0

    for line in filelist:
        tokens = line.split()
        if len(tokens) !=0:
            if (tokens[0] == "CHANGE_LEVEL") and (change_level != ""):
                filelist[lineNumber] = "CHANGE_LEVEL = " + str(change_level) \
                + "\n"

            elif (tokens[0] == "OPUS_FLAG") and (opus_flag != ""):
                filelist[lineNumber] = "OPUS_FLAG = " + str(opus_flag) \
                + "\n"

            elif (tokens[0] == "PEDIGREE") and (pedigree != ""):
                filelist[lineNumber] = "PEDIGREE = " + str(pedigree) \
                + "\n"
                
            elif tokens[0] == "COMMENT":
                commentLineList.append(lineNumber)
        lineNumber = lineNumber + 1

    #Revese the order of the lines in fitshist list
    fitshist.reverse()
    for line in fitshist:
        filelist.insert(commentLineList[0]+1,line)

    # Create populdated LODFILE for writing
    (fullpathfilename, path, filename) = helper.fileinfo(lodfile)
    outfile = open(path+"/pop_"+filename,'w')
    outfile.writelines(filelist)
    outfile.close()

    filehandle.close()
    hdulist.close()


    return
